
#undef TERMCAP

#undef UTMPX

#undef HAVE_UTMP_UT_TV

#undef HAVE_UTMPX_UT_TV

#undef UT_USER

#undef HAS_GETTOS

#undef INET6

#undef GNU_MP

#undef CRYPTOLIB

#undef OPENSSL

#undef AUTHENTICATION

#undef HAVE_SRP

#undef KRB4

#undef KRB4C

#undef KRB5

#undef FORWARD

#undef SPX

#undef RSA_ENCPWD

#undef KRB4_ENCPWD

#undef CAST_ENCRYPTION

#undef OPENSSL_CAST

#undef DES_ENCRYPTION

#undef OPENSSL_DES

#undef CRYPTOLIB_DES

#undef DESLIB4

#undef DESLIB3

#undef ENCRYPTION

#undef NO_RSA

#undef TLS

#undef TLS_KRB5

#undef TLS_SESSION_FILE_CACHE

#undef ZLIB

#undef FWDX_XDM

#undef FWDX_LOOPBACK

#undef FWDX_UNIX_SOCK

#undef FWD_X

#undef ENV_HACK

#undef OLD_ENVIRON

#undef KLUDGELINEMODE

#undef DIAGNOSTICS

#undef TJW

#undef DEFAULT_IM

#undef signal

#undef SOLARIS

#undef IRIX

#undef LINUX

#undef OSF

#undef SCO

#undef LINEMODE

#undef SYSV_TERMIO

#undef NEWINIT

#undef HAVE_fd_set

#undef STREAMSPTY

#undef NO_LOGIN_F

#undef NO_LOGIN_H

#undef LOGIN_R

#undef NO_LOGIN_P

#undef LOGIN_ARGS
